@@ -305,32 +305,32 @@ class PipelineManager:
 
         self._loaded_modules = self._import_tracker.imported_modules
 
-    def update(self, d: dict=None, section_path_str: str=None, pyfileconf_persist: bool = True, **kwargs):
+    def update(self, d_: dict=None, section_path_str: str=None, pyfileconf_persist: bool = True, **kwargs):
         """
         Update the configuration for an item by section path.
 
         The main logic is in _update but this also calls the
         pyfileconf_pre_update and pyfileconf_post_update hooks
 
-        :param d: dictionary of updates
+        :param d_: dictionary of updates
         :param section_path_str: section path of item to be updated
         :param pyfileconf_persist: whether to make changes last through refreshing config
         :param kwargs: kwarg updates
         :return:
         """
         new_updates_list: List[Dict[str, Any]] = plugin_manager.plm.hook.pyfileconf_pre_update(
-            pm=self, d=d, section_path_str=section_path_str, kwargs=kwargs
+            pm=self, d_=d_, section_path_str=section_path_str, kwargs=kwargs
         )
         new_updates_dict: Dict[str, Any] = {k: v for d in new_updates_list for k, v in d.items()}
         if new_updates_dict:
-            if d is not None:
-                d.update(new_updates_dict)
+            if d_ is not None:
+                d_.update(new_updates_dict)
             kwargs.update(new_updates_dict)
 
-        self._update(d, section_path_str=section_path_str, pyfileconf_persist=pyfileconf_persist, **kwargs)
+        self._update(d_, section_path_str=section_path_str, pyfileconf_persist=pyfileconf_persist, **kwargs)
 
         plugin_manager.plm.hook.pyfileconf_post_update(
-            pm=self, d=d, section_path_str=section_path_str, kwargs=kwargs
+            pm=self, d_=d_, section_path_str=section_path_str, kwargs=kwargs
         )
 
     def update_batch(self, updates: Iterable[dict]):
@@ -349,11 +349,11 @@ class PipelineManager:
         )
         updater.update(updates)
 
-    def _update(self, d: dict=None, section_path_str: str=None, pyfileconf_persist: bool = True, **kwargs):
+    def _update(self, d_: dict=None, section_path_str: str=None, pyfileconf_persist: bool = True, **kwargs):
         """
         Update the configuration for an item by section path
 
-        :param d: dictionary of updates
+        :param d_: dictionary of updates
         :param section_path_str: section path of item to be updated
         :param pyfileconf_persist: whether to make changes last through refreshing config
         :param kwargs: kwarg updates
@@ -361,27 +361,19 @@ class PipelineManager:
         """
         from pyfileconf.selector.models.itemview import is_item_view
 
-        self.runner.update(d, section_path_str, pyfileconf_persist=pyfileconf_persist, **kwargs)
-
         if section_path_str:
             # If any of the updates are putting an ItemView as the value, then
             # record that this config is dependent on the config referenced
             # by the ItemView
             all_updates = {**kwargs}
-            if d is not None:
-                all_updates.update(d)
+            if d_ is not None:
+                all_updates.update(d_)
             full_sp = SectionPath.join(self.name, section_path_str)
             for value in all_updates.values():
                 if is_item_view(value):
                     context.add_config_dependency(full_sp, value)
 
-            # Refresh any configs which are dependent on attributes of this config
-            # Dependent configs are determined in Selector._get_real_item
-            full_sp = SectionPath.join(self.name, section_path_str)
-            for dependent_sp in context.force_update_dependencies[full_sp.path_str]:
-                manager = self.__class__.get_manager_by_section_path_str(dependent_sp.path_str)
-                relative_section_path = SectionPath('.'.join(dependent_sp[1:]))
-                manager.refresh(relative_section_path.path_str)
+        self.runner.update(d_, section_path_str, pyfileconf_persist=pyfileconf_persist, **kwargs)
 
     def refresh(self, section_path_str: str):
         """
@@ -543,7 +535,7 @@ class PipelineManager:
             manager_name=self.name,
         )
 
-        self.config = ConfigManager(self.default_config_path)
+        self.config = ConfigManager(self.default_config_path, self.name)
         self.config.load()
 
         self.runner = Runner(
